//
// Copyright (c) 2022, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

using MindFusion.Drawing;

using LinearGradientBrush = MindFusion.Drawing.LinearGradientBrush;


namespace MindFusion.Diagramming.WinForms.Samples.CS.Entities
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void button1_Click(object sender, EventArgs e)
		{
			AddEntityForm form = new AddEntityForm();

			// display entity dialog
			if (form.ShowDialog(this) != DialogResult.OK)
				return;

			// create a table
			float rh = diagram.TableRowHeight;
			float th = diagram.TableCaptionHeight;
			float totalh = th + 4 * rh;
			TableNode t = new TableNode(diagram);
			t.Bounds = new RectangleF(5, 5, 30 + 2 * rh, totalh);
			t.Caption = form.EntityName;
			t.Tag = form.EntityDescription;
			diagram.Nodes.Add(t);

			// add buttons to the table
			Group buttons = diagram.Factory.CreateGroup(t);

			// create the help button
			RectangleF rc = t.Bounds;
			ShapeNode btn = new ShapeNode(diagram);
			btn.Bounds = new RectangleF(rc.Left + 1.4F, rc.Bottom - rh, rh, rh);
			btn.Transparent = true;
			btn.Image = images.Images[3];
			btn.ImageAlign = ImageAlign.Center;
			buttons.AttachToCorner(btn, 3);
			btn.Locked = true;
			btn.Tag = 1;
			diagram.Nodes.Add(btn);

			// create the info button
			btn = new ShapeNode(diagram);
			btn.Bounds = new RectangleF(rc.Left + 2.0F + rh, rc.Bottom - rh, rh, rh);
			btn.Transparent = true;
			btn.Image = images.Images[4];
			btn.ImageAlign = ImageAlign.Center;
			buttons.AttachToCorner(btn, 3);
			btn.Locked = true;
			btn.Tag = 3;
			diagram.Nodes.Add(btn);

			// set table properties
			LinearGradientBrush tbrush = new
                LinearGradientBrush(Color.FromArgb(224, 233, 233), Color.FromArgb(156, 170, 198), 90);

			ColorBlend blend = new ColorBlend(4);
            blend.Colors[0] = Color.FromArgb(224, 233, 233);
			blend.Colors[1] = Color.Black;
            blend.Colors[2] = Color.FromArgb(224, 233, 233);
            blend.Colors[3] = Color.FromArgb(102, 154, 204);
			blend.Positions[0] = 0;
			blend.Positions[1] = th / totalh;
			blend.Positions[2] = th / totalh;
			blend.Positions[3] = 1;
			tbrush.InterpolationColors = blend;

			t.Brush = tbrush;

			t.RowCount = 3;
			t.ColumnCount = 4;

			t.Scrollable = false;
			t.EnabledHandles = AdjustmentHandles.Move;
			t.CellFrameStyle = CellFrameStyle.None;
			t.HandlesStyle = HandlesStyle.HatchHandles3;
			t.Columns[0].Width = rh;
			t.Columns[3].Width = rh;
			t.Columns[1].Width = 15;
			t.Columns[2].Width = 15;
			t.Shape = SimpleShape.RoundedRectangle;
			t.CaptionBrush = new MindFusion.Drawing.SolidBrush(Color.White);

			// set connection points
            AnchorPoint ptin = new AnchorPoint(50, 50, true, false, Color.FromArgb(206, 0, 0), 0);
            AnchorPoint ptout = new AnchorPoint(50, 50, false, true, Color.FromArgb(206, 0, 0), 3);
			ArrayList al = new ArrayList();

			for (int i = 0; i <= 2; i++)
			{
				al.Clear();
				if (!(form.GetInput(i) == null))
				{
					t[0, i].ImageAlign = ImageAlign.Center;
					t[0, i].Image = images.Images[0];
					t[1, i].Text = form.GetInput(i);
					al.Add(ptin.Clone());
				}
				if (!(form.GetOutput(i) == null))
				{
					t[3, i].ImageAlign = ImageAlign.Center;
					t[3, i].Image = images.Images[1];
					t[2, i].Text = form.GetOutput(i);
					t[2, i].TextFormat.Alignment = StringAlignment.Far;
					al.Add(ptout.Clone());
				}
				t.Rows[i].AnchorPattern = new AnchorPattern(
					(AnchorPoint[])al.ToArray(typeof(AnchorPoint)));
			}
		}

		private void Form1_Load(object sender, EventArgs e)
		{
			diagram.ShowDisabledHandles = false;
			diagramView.ModificationStart = ModificationStart.AutoHandles;
		}
	}
}
